==> nextcloud-31.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/lt_LT.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Viešoji nuoroda",
    "Photos" : "Nuotraukos",
    "Your memories under your control" : "Jūsų prisiminimai jūsų rankose",
    "All media" : "Visa medija",
    "Videos" : "Vaizdo įrašai",
    "Albums" : "Albumai",
    "People" : "Žmonės",
    "Folders" : "Aplankai",
    "Favorites" : "Mėgstamos",
    "On this day" : "Šią dieną",
    "Shared with you" : "Bendrinama su jumis",
    "Tags" : "Žymos",
    "Map" : "Žemėlapis",
    "Photos settings" : "Nuotraukų nustatymai",
    "Name of the album" : "Albumo pavadinimas",
    "Location of the album" : "Albumo vieta",
    "Back" : "Atgal",
    "Save" : "Įrašyti",
    "Create album" : "Sukurti albumą",
    "Add to Album" : "Pridėti į albumą",
    "Shared by" : "Bendrina",
    "Create a new album." : "Sukurti naują albumą.",
    "Create new album" : "Sukurti naują albumą",
    "New album" : "Naujas albumas",
    "Failed to update album." : "Nepavyko atnaujinti albumo.",
    "Add people or groups who can edit your album" : "Pridėti žmonių ar grupių, kurie galėtų taisyti jūsų albumą",
    "Search people or groups" : "Ieškoti žmonių ar grupių",
    "No recommendations. Start typing." : "Rekomendacijų nėra. Pradėkite rašyti.",
    "Copy the public link" : "Kopijuoti viešąją nuorodą",
    "Public link copied!" : "Viešoji nuoroda nukopijuota!",
    "Copy public link" : "Kopijuoti viešąją nuorodą",
    "Delete the public link" : "Ištrinti viešąją nuorodą",
    "Share via public link" : "Bendrinti per viešąją nuorodą",
    "This collection does not exist" : "Šios kolekcijos nėra",
    "An error occurred" : "Įvyko klaida",
    "_%n photos_::_%n photos_" : ["%n nuotrauka","%n nuotraukos","%n nuotraukų","%n nuotrauka"],
    "Favorite" : "Mėgstamas",
    "Open the full size \"{name}\" image" : "Atverti viso dydžio „{name}“ paveikslą",
    "Go back" : "Grįžti",
    "Dates" : "Datos",
    "Add to {destination}" : "Pridėti į {destination}",
    "The destination folder is owned by {owner}" : "Paskirties aplanko savininkas yra {owner}",
    "There are no photos or videos yet!" : "Kol kas nėra jokių nuotraukų ar vaizdo įrašų!",
    "_{years} year ago_::_{years} years ago_" : ["Prieš {years} metus","Prieš {years} metus","Prieš {years} metų","Prieš {years} metus"],
    "Enable squared photos view" : "Įjungti kvadratinį nuotraukų rodinį",
    "All folders" : "Visi aplankai",
    "Add folder" : "Pridėti aplanką",
    "Home" : "Namai",
    "View" : "Rodyti",
    "_%n photo_::_%n photos_" : ["%n nuotrauka","%n nuotraukos","%n nuotraukų","%n nuotrauka"],
    "Add photos to this album" : "Pridėti į šį albumą nuotraukų",
    "Open actions menu" : "Atverti veiksmų meniu",
    "Edit album details" : "Taisyti išsamesnę albumo informaciją",
    "Download all files in album" : "Atsisiųsti visus failus šiame albume",
    "Delete album" : "Ištrinti albumą",
    "Download selected files" : "Atsisiųsti pažymėtus failus",
    "Remove selection from album" : "Šalinti žymėjimą iš albumo",
    "This album does not have any photos or videos yet!" : "Šiame albume kol kas nėra jokių nuotraukų ar vaizdo įrašų!",
    "There is no album yet!" : "Kol kas nėra jokių albumų!",
    "This person could not be found" : "Nepavyko rasti šio žmogaus",
    "Rename person" : "Pervadinti žmogų",
    "Merge with different person" : "Sulieti su kitu žmogumi",
    "Download selected photos" : "Atsisiųsti pažymėtas nuotraukas",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Remove person" : "Šalinti žmogų",
    "Name of this person" : "Šio žmogaus vardas",
    "Save." : "Įrašyti.",
    "This might take some time depending on the size of your photo library." : "Tai, priklausomai nuo jūsų nuotraukų bibliotekos dydžio, gali šiek tiek užtrukti.",
    "Recognized people will show up here" : "Čia bus rodomi atpažinti žmonės",
    "This folder does not exist" : "Šio aplanko nėra",
    "Loading folders…" : "Įkeliami aplankai…",
    "No photos in here" : "Čia nuotraukų nėra",
    "Back to tags overview" : "Atgal į žymų apžvalgą",
    "No photos with this tag yet" : "Kol kas nėra nuotraukų, turinčių šią žymą",
    "No tags yet" : "Kol kas žymų nėra",
    "Photos with tags will show up here" : "Čia bus rodomos nuotraukos, turinčios žymas",
    "Popular tags" : "Populiarios žymos",
    "All tags" : "Visos žymos",
    "Add to album" : "Pridėti į albumą",
    "Delete selection" : "Ištrinti žymėjimą",
    "No photos or videos in here" : "Čia nėra jokių nuotraukų ar vaizdo įrašų",
    "Failed to fetch faces list." : "Nepavyko gauti veidų sąrašo.",
    "All your media" : "Visa jūsų medija",
    "Shared Albums" : "Bendrinami albumai",
    "Tagged photos" : "Nuotraukos, turinčios žymas",
    "Last week" : "Praeitą savaitę",
    "{startDate} to {endDate}" : "Nuo {startDate} iki {endDate}",
    "Details" : "Išsamiau",
    "Could not load photos folder" : "Nepavyko įkelti nuotraukų aplanko",
    "Back to {folder}" : "Atgal į {folder}",
    "Share this folder" : "Bendrinti šį aplanką",
    "Loading folders …" : "Įkeliami aplankai…",
    "One of the source folders does not exists" : "Vieno iš šaltinio aplankų nėra",
    "Add" : "Pridėti"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/lt_LT.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Viešoji nuoroda",
    "Photos" : "Nuotraukos",
    "Your memories under your control" : "Jūsų prisiminimai jūsų rankose",
    "All media" : "Visa medija",
    "Videos" : "Vaizdo įrašai",
    "Albums" : "Albumai",
    "People" : "Žmonės",
    "Folders" : "Aplankai",
    "Favorites" : "Mėgstamos",
    "On this day" : "Šią dieną",
    "Shared with you" : "Bendrinama su jumis",
    "Tags" : "Žymos",
    "Map" : "Žemėlapis",
    "Photos settings" : "Nuotraukų nustatymai",
    "This name is already in use." : "Šis pavadinimas jau yra naudojamas.",
    "Invalid filename." : "Neteisingas failo pavadinimas.",
    "Name of the album" : "Albumo pavadinimas",
    "Location of the album" : "Albumo vieta",
    "Back" : "Atgal",
    "Save" : "Įrašyti",
    "Create album" : "Sukurti albumą",
    "Add to Album" : "Pridėti į albumą",
    "Shared by" : "Bendrina",
    "Create a new album." : "Sukurti naują albumą.",
    "Create new album" : "Sukurti naują albumą",
    "New album" : "Naujas albumas",
    "Failed to update album." : "Nepavyko atnaujinti albumo.",
    "Add people or groups who can edit your album" : "Pridėti žmonių ar grupių, kurie galėtų taisyti jūsų albumą",
    "Search people or groups" : "Ieškoti žmonių ar grupių",
    "No recommendations. Start typing." : "Rekomendacijų nėra. Pradėkite rašyti.",
    "Copy the public link" : "Kopijuoti viešąją nuorodą",
    "Public link copied!" : "Viešoji nuoroda nukopijuota!",
    "Copy public link" : "Kopijuoti viešąją nuorodą",
    "Delete the public link" : "Ištrinti viešąją nuorodą",
    "Share via public link" : "Bendrinti per viešąją nuorodą",
    "This collection does not exist" : "Šios kolekcijos nėra",
    "An error occurred" : "Įvyko klaida",
    "_%n photos_::_%n photos_" : ["%n nuotrauka","%n nuotraukos","%n nuotraukų","%n nuotrauka"],
    "Favorite" : "Mėgstamas",
    "Open the full size \"{name}\" image" : "Atverti viso dydžio „{name}“ paveikslą",
    "Go back" : "Grįžti",
    "Dates" : "Datos",
    "Add to {destination}" : "Pridėti į {destination}",
    "The destination folder is owned by {owner}" : "Paskirties aplanko savininkas yra {owner}",
    "There are no photos or videos yet!" : "Kol kas nėra jokių nuotraukų ar vaizdo įrašų!",
    "_{years} year ago_::_{years} years ago_" : ["Prieš {years} metus","Prieš {years} metus","Prieš {years} metų","Prieš {years} metus"],
    "All folders" : "Visi aplankai",
    "Add folder" : "Pridėti aplanką",
    "Home" : "Namai",
    "Upload folder" : "Įkelti aplanką",
    "General" : "Bendra",
    "_%n photo_::_%n photos_" : ["%n nuotrauka","%n nuotraukos","%n nuotraukų","%n nuotrauka"],
    "Add photos to this album" : "Pridėti į šį albumą nuotraukų",
    "Open actions menu" : "Atverti veiksmų meniu",
    "Edit album details" : "Taisyti išsamesnę albumo informaciją",
    "Download all files in album" : "Atsisiųsti visus failus šiame albume",
    "Delete album" : "Ištrinti albumą",
    "Download selected files" : "Atsisiųsti pažymėtus failus",
    "Remove selection from album" : "Šalinti žymėjimą iš albumo",
    "This album does not have any photos or videos yet!" : "Šiame albume kol kas nėra jokių nuotraukų ar vaizdo įrašų!",
    "There is no album yet!" : "Kol kas nėra jokių albumų!",
    "This person could not be found" : "Nepavyko rasti šio žmogaus",
    "Rename person" : "Pervadinti žmogų",
    "Merge with different person" : "Sulieti su kitu žmogumi",
    "Download selected photos" : "Atsisiųsti pažymėtas nuotraukas",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Remove person" : "Šalinti žmogų",
    "Name of this person" : "Šio žmogaus vardas",
    "Save." : "Įrašyti.",
    "This might take some time depending on the size of your photo library." : "Tai, priklausomai nuo jūsų nuotraukų bibliotekos dydžio, gali šiek tiek užtrukti.",
    "Recognized people will show up here" : "Čia bus rodomi atpažinti žmonės",
    "This folder does not exist" : "Šio aplanko nėra",
    "Loading folders…" : "Įkeliami aplankai…",
    "No photos in here" : "Čia nuotraukų nėra",
    "Back to tags overview" : "Atgal į žymų apžvalgą",
    "No photos with this tag yet" : "Kol kas nėra nuotraukų, turinčių šią žymą",
    "No tags yet" : "Kol kas žymų nėra",
    "Photos with tags will show up here" : "Čia bus rodomos nuotraukos, turinčios žymas",
    "Popular tags" : "Populiarios žymos",
    "All tags" : "Visos žymos",
    "Add to album" : "Pridėti į albumą",
    "Delete selection" : "Ištrinti žymėjimą",
    "No photos or videos in here" : "Čia nėra jokių nuotraukų ar vaizdo įrašų",
    "Failed to fetch faces list." : "Nepavyko gauti veidų sąrašo.",
    "All your media" : "Visa jūsų medija",
    "Shared Albums" : "Bendrinami albumai",
    "Tagged photos" : "Nuotraukos, turinčios žymas",
    "Last week" : "Praeitą savaitę",
    "{startDate} to {endDate}" : "Nuo {startDate} iki {endDate}",
    "Details" : "Išsamiau",
    "Cancel" : "Atsisakyti",
    "Confirm" : "Patvirtinti",
    "Could not load photos folder" : "Nepavyko įkelti nuotraukų aplanko",
    "Back to {folder}" : "Atgal į {folder}",
    "Share this folder" : "Bendrinti šį aplanką",
    "Enable squared photos view" : "Įjungti kvadratinį nuotraukų rodinį",
    "View" : "Rodyti",
    "Loading folders …" : "Įkeliami aplankai…",
    "Add" : "Pridėti"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
